% Example script for testing of dithered electroplating precision

% Edit the parameters below to see how this affects the results
% ---------- BEGIN USER-EDITABLE BLOCK ------------------------
channel = 9;
resistance = 10e6; % resistance
desired_currents = -250e-9:20e-9:250e-9;
% channel = 5; 
% resistance = 20e6; % resistance
% desired_currents = -150e-9:10e-9:150e-9;
% channel = 3; 
% resistance = 4.7e6; % resistance
% desired_currents = -500e-9:50e-9:500e-9;
% channel = 15; 
% resistance = 13.3e6; % resistance
% desired_currents = -250e-9:25e-9:250e-9;
% channel = 10;  
% resistance = 1e6; % resistance
% desired_currents = -2500e-9:250e-9:2500e-9;

pla_time = 1;         % [s] Plating time
samdiscard = 200; % Discard some first samples (transient)
% ---------- END OF USER-EDITABLE BLOCK -----------------------

%      This file is a part of nanoZ Matlab SDK
%   nanoZ SDK license terms and conditions apply.

clear nanoz   % Close any nanoZ handles that might have been erroneously left open
devs = nanoz('enumdevs');
if isempty(devs)
    disp('No nanoZ devices attached, or all are in use by other Windows applications');
    return;
end

% This script works on the first found nanoZ in the system
hdev = nanoz('open',devs{1},64);
fprintf('\nOpened nanoZ %s\n',devs{1});

% Get waveform capabilities to determine the ADC sampling frequency
wfcaps = nanoz('getwaveformcaps',hdev);
fs = wfcaps.fs_adc;
% Get plating capabilities
placaps = nanoz('getplatingcaps',hdev);

nanoz('selectchannel',hdev,channel);

achieved_currents = zeros(size(desired_currents));
tested_currents = zeros(size(desired_currents));
pla_nsam = round(fs*pla_time); 
signaldatas = zeros(length(desired_currents),pla_nsam);

figure(1);
clf;
cla;
hold on;
title('ADC waveforms');
xlabel('Time [s]');
ylabel('Voltage [V]');
% hold on;
% title('DAC waveforms');
% xlabel('Time [s]');
% ylabel('Raw sample value [1]');
for i=1:length(desired_currents)
    [signaldata,achieved_currents(i)] = plating_loop_dc(hdev,desired_currents(i),pla_nsam+samdiscard);
    signaldatad = signaldata(samdiscard+1:pla_nsam+samdiscard);
    signaldatas(i,:) = signaldatad;
    t = (0:pla_nsam-1)/fs;
    figure(1);
    plot(t,signaldata(1:pla_nsam));
    v = mean(signaldatad); %Voltage feedback
    tested_currents(i) = v/resistance;
end
hold off
grid on
figure(2);
subplot(121);
plot(achieved_currents,tested_currents);
title('Tested vs. predicted currents');
xlabel('Predicted current [A]');
ylabel('Tested current [A]');
grid on
axis('tight')
subplot(122);
err = achieved_currents-tested_currents;
plot(achieved_currents,err);
title('Current prediction error');
xlabel('Predicted current [A]');
ylabel('Current prediction error [A]');
grid on
axis('tight')
nanoz('close',hdev);
[maxer, argmax] = max(abs(err));
fprintf('Average error = %gnA\n',mean(abs(err)));
fprintf('Maximum error = %gnA (%d%%)\n',maxer,round(maxer/abs(achieved_currents(argmax))*100));
